helpers/tip.helpers library

Functions

calculateTip(double price, double tipRate) double
Calculates the tip on a price before VAT.
getTipAmount(double price, double tipRate) double
Calculates the tip amount for a given price and tip percentage.
getTipRate(double price, double tipAmount) double
Calculates the tip rate based on the price and tip amount.