logic/services/services library

Classes

MatexFiancialMetadataProvider<T>
MatexFinancialInstrumentExchangeService
An abstract class representing the exchange service for financial instruments within the Matex application. It provides a contract for the exchange rate querying and resource disposal.
MatexFinancialInstrumentMedatataService
MatexFinancialInstrumentPairMetadataService