ui/ui library

Classes

FusexTakeProfitSwitchField
MatexAppSettingsPrimaryCurrencyField
A widget that displays a select currency field for the user's primary currency.
MatexAppSettingsUserCountrySelectField
A widget that displays a select country field for the user's primary country.
MatexFinancialAmountSwitchField
A widget that allows the user to switch between an amount field and a percent field.
MatexFinancialCountryBuilder
MatexFinancialCurrencyBuilder
MatexFinancialCurrencyFavoriteIcon
A widget that displays a heart icon indicating whether a currency is marked as favorite or not. The widget is built using the BlocBuilderWidget class from the tbloc package.
MatexFinancialFrequencySelectField
Represents a widget for selecting financial frequencies.
MatexFinancialInstrumentFavoriteIcon
A widget that displays a heart icon indicating whether a financial instrument is marked as favorite or not. The widget is built using the BlocBuilderWidget class from the tbloc package.
MatexFinancialPositionSizeSwitchField
MatexFinancialSelectAmounTypeField
MatexFinancialSelectAmounTypeFieldState
MatexFinancialSelectCountryField
A Flutter widget for displaying a selectable list of countries.
MatexFinancialSelectCurrencyField
A Flutter widget for displaying a selectable list of currencies.
MatexFinancialSelectInstrumentField
MatexFinancialSelectInstrumentFieldState
MatexFinancialSelectLeverageField
MatexFinancialSelectLeverageFieldState
MatexFinancialSelectPivotPointsMethodsField
MatexFinancialSelectPivotPointsMethodsFieldState