logic/logic library
Classes
- MatexCurrencyFavoriteJob
-
MatexFiancialMetadataProvider<
T> - MatexFinancialInstrumentCalculatorBlocFields
- An abstract class representing fields for a financial instrument calculator in a Bloc pattern. This class provides the foundation for handling calculations related to various financial instruments like currency pairs or stocks against a currency.
- MatexFinancialInstrumentExchangeService
- An abstract class representing the exchange service for financial instruments within the Matex application. It provides a contract for the exchange rate querying and resource disposal.
- MatexFinancialInstrumentMedatataService
- MatexFinancialInstrumentPairMetadataService
- MatexFinancialInstrumentsJob
- MatexInstrumentFavoriteJob
Enums
Extensions
- FastFinancialAmountSwitchFieldTypeX on FastFinancialAmountSwitchFieldType
- MatexFinancialFrequencyX on MatexFinancialFrequency
- MatexPivotPointsMethodsX on MatexPivotPointsMethods
- MatexPositionSizeTypeX on MatexPositionSizeType
- MatexPositionX on MatexPosition
- MatexTrendX on MatexTrend
- MatexVatCalculationStrategyX on MatexVatCalculationStrategy
Constants
- kMatexDefaultLeverage → const double
- kMatexDefaultPipDecimalPlaces → const int
-
kMatexFibonacciExtensionLevels
→ const List<
double> -
kMatexFibonacciRetracementLevels
→ const List<
double> -
kMatexLeverages
→ const List<
double> - kMatexQuoteMaxFractionDigits → const int
Functions
-
formatLeverage(
num leverage, {String? locale, int? maximumFractionDigits = 2, int? minimumFractionDigits}) → String -
getLocaleKeyForFinancialFrequency(
MatexFinancialFrequency frequency) → String - Gets the locale key for a given financial frequency.
-
getPaymentFrequency(
MatexFinancialFrequency frequency) → int - Determines the number of payments per year based on the frequency.
-
getRiskRewardRatioColorForValue(
BuildContext context, double? reward) → Color? -
takeProfitSwitchFieldTypeFromString(
String? string) → MatexTakeProfitSwitchFieldType?